Index: sdk/lib/_internal/js_runtime/lib/js_rti.dart |
diff --git a/sdk/lib/_internal/js_runtime/lib/js_rti.dart b/sdk/lib/_internal/js_runtime/lib/js_rti.dart |
index 91254ef2dad1901511974373cb340ff30e9d1793..f9cd6985f06bedc837c40f3ac4961bf4b436992b 100644 |
--- a/sdk/lib/_internal/js_runtime/lib/js_rti.dart |
+++ b/sdk/lib/_internal/js_runtime/lib/js_rti.dart |
@@ -452,9 +452,9 @@ bool isSubtype(var s, var t) { |
if (isDartFunctionType(t)) { |
return isFunctionSubtype(s, t); |
} |
// Check function types against the Function class. |
if (isDartFunctionType(s)) { |
- return isDartFunctionTypeRti(t); |
+ return isDartFunctionTypeRti(t) || isDartObjectTypeRti(t); |
} |
// Get the object describing the class and check for the subtyping flag |
@@ -452,9 +452,9 @@ bool isSubtype(var s, var t) { |
return isFunctionSubtype(s, t); |
} |
- // Check function types against the Function class. |
+ // Check function types against the Function class and the Object class. |
if (isDartFunctionType(s)) { |